show_properties

Function show_properties 

pub fn show_properties(file_path: PathBuf) -> Result<(), Box<dyn Error>>
Uses the default file manager to show properties of the file at the given path.

Arguments

  • file_path - A PathBuf that holds the path to the file.

Errors

Returns an error if the properties cannot be shown.